/* This file is automatically generated by configure.  Do not modify by hand. */
/* Define if compiling with the default_modules module files.  */
#define USING_DEFAULT_MODULES_MODULE 1
 
/* Define if compiling with the mibII/mta_sendmail module files.  */
#define USING_MIBII_MTA_SENDMAIL_MODULE 1
 
/* Define if compiling with the smux module files.  */
#define USING_SMUX_MODULE 1
 
/* Define if compiling with the snmpv3mibs module files.  */
#define USING_SNMPV3MIBS_MODULE 1
 
/* Define if compiling with the mibII module files.  */
#define USING_MIBII_MODULE 1
 
/* Define if compiling with the ucd_snmp module files.  */
#define USING_UCD_SNMP_MODULE 1
 
/* Define if compiling with the notification module files.  */
#define USING_NOTIFICATION_MODULE 1
 
/* Define if compiling with the notification-log-mib module files.  */
#define USING_NOTIFICATION_LOG_MIB_MODULE 1
 
/* Define if compiling with the target module files.  */
#define USING_TARGET_MODULE 1
 
/* Define if compiling with the agent_mibs module files.  */
#define USING_AGENT_MIBS_MODULE 1
 
/* Define if compiling with the agentx module files.  */
#define USING_AGENTX_MODULE 1
 
/* Define if compiling with the disman/event module files.  */
#define USING_DISMAN_EVENT_MODULE 1
 
/* Define if compiling with the disman/schedule module files.  */
#define USING_DISMAN_SCHEDULE_MODULE 1
 
/* Define if compiling with the utilities module files.  */
#define USING_UTILITIES_MODULE 1
 
/* Define if compiling with the host module files.  */
#define USING_HOST_MODULE 1
 
/* Define if compiling with the snmpv3/snmpEngine module files.  */
#define USING_SNMPV3_SNMPENGINE_MODULE 1
 
/* Define if compiling with the snmpv3/snmpMPDStats module files.  */
#define USING_SNMPV3_SNMPMPDSTATS_MODULE 1
 
/* Define if compiling with the snmpv3/usmStats module files.  */
#define USING_SNMPV3_USMSTATS_MODULE 1
 
/* Define if compiling with the snmpv3/usmUser module files.  */
#define USING_SNMPV3_USMUSER_MODULE 1
 
/* Define if compiling with the mibII/system_mib module files.  */
#define USING_MIBII_SYSTEM_MIB_MODULE 1
 
/* Define if compiling with the mibII/sysORTable module files.  */
#define USING_MIBII_SYSORTABLE_MODULE 1
 
/* Define if compiling with the mibII/snmp_mib module files.  */
#define USING_MIBII_SNMP_MIB_MODULE 1
 
/* Define if compiling with the mibII/vacm_vars module files.  */
#define USING_MIBII_VACM_VARS_MODULE 1
 
/* Define if compiling with the mibII/setSerialNo module files.  */
#define USING_MIBII_SETSERIALNO_MODULE 1
 
/* Define if compiling with the mibII/at module files.  */
#define USING_MIBII_AT_MODULE 1
 
/* Define if compiling with the mibII/ifTable module files.  */
#define USING_MIBII_IFTABLE_MODULE 1
 
/* Define if compiling with the mibII/ip module files.  */
#define USING_MIBII_IP_MODULE 1
 
/* Define if compiling with the mibII/tcp module files.  */
#define USING_MIBII_TCP_MODULE 1
 
/* Define if compiling with the mibII/udp module files.  */
#define USING_MIBII_UDP_MODULE 1
 
/* Define if compiling with the mibII/ipv6 module files.  */
#define USING_MIBII_IPV6_MODULE 1
 
/* Define if compiling with the mibII/icmp module files.  */
#define USING_MIBII_ICMP_MODULE 1
 
/* Define if compiling with the if-mib module files.  */
#define USING_IF_MIB_MODULE 1
 
/* Define if compiling with the ip-mib module files.  */
#define USING_IP_MIB_MODULE 1
 
/* Define if compiling with the ip-forward-mib module files.  */
#define USING_IP_FORWARD_MIB_MODULE 1
 
/* Define if compiling with the tcp-mib module files.  */
#define USING_TCP_MIB_MODULE 1
 
/* Define if compiling with the udp-mib module files.  */
#define USING_UDP_MIB_MODULE 1
 
/* Define if compiling with the ucd-snmp/proc module files.  */
#define USING_UCD_SNMP_PROC_MODULE 1
 
/* Define if compiling with the ucd-snmp/versioninfo module files.  */
#define USING_UCD_SNMP_VERSIONINFO_MODULE 1
 
/* Define if compiling with the ucd-snmp/pass module files.  */
#define USING_UCD_SNMP_PASS_MODULE 1
 
/* Define if compiling with the ucd-snmp/pass_persist module files.  */
#define USING_UCD_SNMP_PASS_PERSIST_MODULE 1
 
/* Define if compiling with the ucd-snmp/disk_hw module files.  */
#define USING_UCD_SNMP_DISK_HW_MODULE 1
 
/* Define if compiling with the ucd-snmp/loadave module files.  */
#define USING_UCD_SNMP_LOADAVE_MODULE 1
 
/* Define if compiling with the agent/extend module files.  */
#define USING_AGENT_EXTEND_MODULE 1
 
/* Define if compiling with the ucd-snmp/errormib module files.  */
#define USING_UCD_SNMP_ERRORMIB_MODULE 1
 
/* Define if compiling with the ucd-snmp/file module files.  */
#define USING_UCD_SNMP_FILE_MODULE 1
 
/* Define if compiling with the ucd-snmp/dlmod module files.  */
#define USING_UCD_SNMP_DLMOD_MODULE 1
 
/* Define if compiling with the ucd-snmp/proxy module files.  */
#define USING_UCD_SNMP_PROXY_MODULE 1
 
/* Define if compiling with the ucd-snmp/logmatch module files.  */
#define USING_UCD_SNMP_LOGMATCH_MODULE 1
 
/* Define if compiling with the ucd-snmp/memory module files.  */
#define USING_UCD_SNMP_MEMORY_MODULE 1
 
/* Define if compiling with the ucd-snmp/vmstat module files.  */
#define USING_UCD_SNMP_VMSTAT_MODULE 1
 
/* Define if compiling with the notification/snmpNotifyTable module files.  */
#define USING_NOTIFICATION_SNMPNOTIFYTABLE_MODULE 1
 
/* Define if compiling with the snmp-notification-mib/snmpNotifyFilterTable module files.  */
#define USING_SNMP_NOTIFICATION_MIB_SNMPNOTIFYFILTERTABLE_MODULE 1
 
/* Define if compiling with the notification/snmpNotifyFilterProfileTable module files.  */
#define USING_NOTIFICATION_SNMPNOTIFYFILTERPROFILETABLE_MODULE 1
 
/* Define if compiling with the notification-log-mib/notification_log module files.  */
#define USING_NOTIFICATION_LOG_MIB_NOTIFICATION_LOG_MODULE 1
 
/* Define if compiling with the target/snmpTargetAddrEntry module files.  */
#define USING_TARGET_SNMPTARGETADDRENTRY_MODULE 1
 
/* Define if compiling with the target/snmpTargetParamsEntry module files.  */
#define USING_TARGET_SNMPTARGETPARAMSENTRY_MODULE 1
 
/* Define if compiling with the target/target module files.  */
#define USING_TARGET_TARGET_MODULE 1
 
/* Define if compiling with the target/target_counters module files.  */
#define USING_TARGET_TARGET_COUNTERS_MODULE 1
 
/* Define if compiling with the agent/nsTransactionTable module files.  */
#define USING_AGENT_NSTRANSACTIONTABLE_MODULE 1
 
/* Define if compiling with the agent/nsModuleTable module files.  */
#define USING_AGENT_NSMODULETABLE_MODULE 1
 
/* Define if compiling with the agent/nsDebug module files.  */
#define USING_AGENT_NSDEBUG_MODULE 1
 
/* Define if compiling with the agent/nsCache module files.  */
#define USING_AGENT_NSCACHE_MODULE 1
 
/* Define if compiling with the agent/nsLogging module files.  */
#define USING_AGENT_NSLOGGING_MODULE 1
 
/* Define if compiling with the agent/nsVacmAccessTable module files.  */
#define USING_AGENT_NSVACMACCESSTABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteScalars module files.  */
#define USING_DISMAN_EVENT_MTESCALARS_MODULE 1
 
/* Define if compiling with the disman/event/mteTrigger module files.  */
#define USING_DISMAN_EVENT_MTETRIGGER_MODULE 1
 
/* Define if compiling with the disman/event/mteTriggerTable module files.  */
#define USING_DISMAN_EVENT_MTETRIGGERTABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteTriggerDeltaTable module files.  */
#define USING_DISMAN_EVENT_MTETRIGGERDELTATABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteTriggerExistenceTable module files.  */
#define USING_DISMAN_EVENT_MTETRIGGEREXISTENCETABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteTriggerBooleanTable module files.  */
#define USING_DISMAN_EVENT_MTETRIGGERBOOLEANTABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteTriggerThresholdTable module files.  */
#define USING_DISMAN_EVENT_MTETRIGGERTHRESHOLDTABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteTriggerConf module files.  */
#define USING_DISMAN_EVENT_MTETRIGGERCONF_MODULE 1
 
/* Define if compiling with the disman/event/mteEvent module files.  */
#define USING_DISMAN_EVENT_MTEEVENT_MODULE 1
 
/* Define if compiling with the disman/event/mteEventTable module files.  */
#define USING_DISMAN_EVENT_MTEEVENTTABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteEventSetTable module files.  */
#define USING_DISMAN_EVENT_MTEEVENTSETTABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteEventNotificationTable module files.  */
#define USING_DISMAN_EVENT_MTEEVENTNOTIFICATIONTABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteEventConf module files.  */
#define USING_DISMAN_EVENT_MTEEVENTCONF_MODULE 1
 
/* Define if compiling with the disman/event/mteObjects module files.  */
#define USING_DISMAN_EVENT_MTEOBJECTS_MODULE 1
 
/* Define if compiling with the disman/event/mteObjectsTable module files.  */
#define USING_DISMAN_EVENT_MTEOBJECTSTABLE_MODULE 1
 
/* Define if compiling with the disman/event/mteObjectsConf module files.  */
#define USING_DISMAN_EVENT_MTEOBJECTSCONF_MODULE 1
 
/* Define if compiling with the disman/schedule/schedCore module files.  */
#define USING_DISMAN_SCHEDULE_SCHEDCORE_MODULE 1
 
/* Define if compiling with the disman/schedule/schedConf module files.  */
#define USING_DISMAN_SCHEDULE_SCHEDCONF_MODULE 1
 
/* Define if compiling with the disman/schedule/schedTable module files.  */
#define USING_DISMAN_SCHEDULE_SCHEDTABLE_MODULE 1
 
/* Define if compiling with the utilities/override module files.  */
#define USING_UTILITIES_OVERRIDE_MODULE 1
 
/* Define if compiling with the host/hrh_storage module files.  */
#define USING_HOST_HRH_STORAGE_MODULE 1
 
/* Define if compiling with the host/hrh_filesys module files.  */
#define USING_HOST_HRH_FILESYS_MODULE 1
 
/* Define if compiling with the host/hrSWInstalledTable module files.  */
#define USING_HOST_HRSWINSTALLEDTABLE_MODULE 1
 
/* Define if compiling with the host/hrSWRunTable module files.  */
#define USING_HOST_HRSWRUNTABLE_MODULE 1
 
/* Define if compiling with the host/hr_system module files.  */
#define USING_HOST_HR_SYSTEM_MODULE 1
 
/* Define if compiling with the host/hr_device module files.  */
#define USING_HOST_HR_DEVICE_MODULE 1
 
/* Define if compiling with the host/hr_other module files.  */
#define USING_HOST_HR_OTHER_MODULE 1
 
/* Define if compiling with the host/hr_proc module files.  */
#define USING_HOST_HR_PROC_MODULE 1
 
/* Define if compiling with the host/hr_network module files.  */
#define USING_HOST_HR_NETWORK_MODULE 1
 
/* Define if compiling with the host/hr_print module files.  */
#define USING_HOST_HR_PRINT_MODULE 1
 
/* Define if compiling with the host/hr_disk module files.  */
#define USING_HOST_HR_DISK_MODULE 1
 
/* Define if compiling with the host/hr_partition module files.  */
#define USING_HOST_HR_PARTITION_MODULE 1
 
/* Define if compiling with the util_funcs/header_generic module files.  */
#define USING_UTIL_FUNCS_HEADER_GENERIC_MODULE 1
 
/* Define if compiling with the util_funcs module files.  */
#define USING_UTIL_FUNCS_MODULE 1
 
/* Define if compiling with the mibII/updates module files.  */
#define USING_MIBII_UPDATES_MODULE 1
 
/* Define if compiling with the mibII/vacm_context module files.  */
#define USING_MIBII_VACM_CONTEXT_MODULE 1
 
/* Define if compiling with the mibII/data_access/at_sysctl module files.  */
#define USING_MIBII_DATA_ACCESS_AT_SYSCTL_MODULE 1
 
/* Define if compiling with the mibII/data_access/at_unix module files.  */
#define USING_MIBII_DATA_ACCESS_AT_UNIX_MODULE 1
 
/* Define if compiling with the if-mib/ifTable module files.  */
#define USING_IF_MIB_IFTABLE_MODULE 1
 
/* Define if compiling with the mibII/ipAddr module files.  */
#define USING_MIBII_IPADDR_MODULE 1
 
/* Define if compiling with the mibII/var_route module files.  */
#define USING_MIBII_VAR_ROUTE_MODULE 1
 
/* Define if compiling with the mibII/route_write module files.  */
#define USING_MIBII_ROUTE_WRITE_MODULE 1
 
/* Define if compiling with the mibII/tcpTable module files.  */
#define USING_MIBII_TCPTABLE_MODULE 1
 
/* Define if compiling with the mibII/udpTable module files.  */
#define USING_MIBII_UDPTABLE_MODULE 1
 
/* Define if compiling with the mibII/kernel_sysctl module files.  */
#define USING_MIBII_KERNEL_SYSCTL_MODULE 1
 
/* Define if compiling with the if-mib/ifXTable module files.  */
#define USING_IF_MIB_IFXTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ipAddressTable module files.  */
#define USING_IP_MIB_IPADDRESSTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ipAddressPrefixTable module files.  */
#define USING_IP_MIB_IPADDRESSPREFIXTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ipDefaultRouterTable module files.  */
#define USING_IP_MIB_IPDEFAULTROUTERTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/inetNetToMediaTable module files.  */
#define USING_IP_MIB_INETNETTOMEDIATABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ipSystemStatsTable module files.  */
#define USING_IP_MIB_IPSYSTEMSTATSTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ip_scalars module files.  */
#define USING_IP_MIB_IP_SCALARS_MODULE 1
 
/* Define if compiling with the ip-forward-mib/ipCidrRouteTable module files.  */
#define USING_IP_FORWARD_MIB_IPCIDRROUTETABLE_MODULE 1
 
/* Define if compiling with the ip-forward-mib/inetCidrRouteTable module files.  */
#define USING_IP_FORWARD_MIB_INETCIDRROUTETABLE_MODULE 1
 
/* Define if compiling with the tcp-mib/tcpConnectionTable module files.  */
#define USING_TCP_MIB_TCPCONNECTIONTABLE_MODULE 1
 
/* Define if compiling with the tcp-mib/tcpListenerTable module files.  */
#define USING_TCP_MIB_TCPLISTENERTABLE_MODULE 1
 
/* Define if compiling with the udp-mib/udpEndpointTable module files.  */
#define USING_UDP_MIB_UDPENDPOINTTABLE_MODULE 1
 
/* Define if compiling with the util_funcs/restart module files.  */
#define USING_UTIL_FUNCS_RESTART_MODULE 1
 
/* Define if compiling with the ucd-snmp/pass_common module files.  */
#define USING_UCD_SNMP_PASS_COMMON_MODULE 1
 
/* Define if compiling with the util_funcs/header_simple_table module files.  */
#define USING_UTIL_FUNCS_HEADER_SIMPLE_TABLE_MODULE 1
 
/* Define if compiling with the hardware/fsys module files.  */
#define USING_HARDWARE_FSYS_MODULE 1
 
/* Define if compiling with the hardware/memory module files.  */
#define USING_HARDWARE_MEMORY_MODULE 1
 
/* Define if compiling with the hardware/cpu module files.  */
#define USING_HARDWARE_CPU_MODULE 1
 
/* Define if compiling with the notification/snmpNotifyTable_data module files.  */
#define USING_NOTIFICATION_SNMPNOTIFYTABLE_DATA_MODULE 1
 
/* Define if compiling with the header_complex module files.  */
#define USING_HEADER_COMPLEX_MODULE 1
 
/* Define if compiling with the snmp-notification-mib/snmpNotifyFilterTable/snmpNotifyFilterTable_data_storage module files.  */
#define USING_SNMP_NOTIFICATION_MIB_SNMPNOTIFYFILTERTABLE_SNMPNOTIFYFILTERTABLE_DATA_STORAGE_MODULE 1
 
/* Define if compiling with the snmp-notification-mib/snmpNotifyFilterTable/snmpNotifyFilterTable module files.  */
#define USING_SNMP_NOTIFICATION_MIB_SNMPNOTIFYFILTERTABLE_SNMPNOTIFYFILTERTABLE_MODULE 1
 
/* Define if compiling with the notification/snmpNotifyFilterProfileTable_data module files.  */
#define USING_NOTIFICATION_SNMPNOTIFYFILTERPROFILETABLE_DATA_MODULE 1
 
/* Define if compiling with the target/snmpTargetAddrEntry_data module files.  */
#define USING_TARGET_SNMPTARGETADDRENTRY_DATA_MODULE 1
 
/* Define if compiling with the target/snmpTargetParamsEntry_data module files.  */
#define USING_TARGET_SNMPTARGETPARAMSENTRY_DATA_MODULE 1
 
/* Define if compiling with the host/data_access/swinst module files.  */
#define USING_HOST_DATA_ACCESS_SWINST_MODULE 1
 
/* Define if compiling with the host/data_access/swrun module files.  */
#define USING_HOST_DATA_ACCESS_SWRUN_MODULE 1
 
/* Define if compiling with the host/hrSWRunPerfTable module files.  */
#define USING_HOST_HRSWRUNPERFTABLE_MODULE 1
 
/* Define if compiling with the if-mib/ifTable/ifTable module files.  */
#define USING_IF_MIB_IFTABLE_IFTABLE_MODULE 1
 
/* Define if compiling with the if-mib/ifXTable/ifXTable module files.  */
#define USING_IF_MIB_IFXTABLE_IFXTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ipAddressTable/ipAddressTable module files.  */
#define USING_IP_MIB_IPADDRESSTABLE_IPADDRESSTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ipAddressPrefixTable/ipAddressPrefixTable module files.  */
#define USING_IP_MIB_IPADDRESSPREFIXTABLE_IPADDRESSPREFIXTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ipDefaultRouterTable/ipDefaultRouterTable module files.  */
#define USING_IP_MIB_IPDEFAULTROUTERTABLE_IPDEFAULTROUTERTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/arp module files.  */
#define USING_IP_MIB_DATA_ACCESS_ARP_MODULE 1
 
/* Define if compiling with the ip-mib/inetNetToMediaTable/inetNetToMediaTable module files.  */
#define USING_IP_MIB_INETNETTOMEDIATABLE_INETNETTOMEDIATABLE_MODULE 1
 
/* Define if compiling with the ip-mib/inetNetToMediaTable/inetNetToMediaTable_interface module files.  */
#define USING_IP_MIB_INETNETTOMEDIATABLE_INETNETTOMEDIATABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the ip-mib/inetNetToMediaTable/inetNetToMediaTable_data_access module files.  */
#define USING_IP_MIB_INETNETTOMEDIATABLE_INETNETTOMEDIATABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/systemstats module files.  */
#define USING_IP_MIB_DATA_ACCESS_SYSTEMSTATS_MODULE 1
 
/* Define if compiling with the ip-mib/ipSystemStatsTable/ipSystemStatsTable module files.  */
#define USING_IP_MIB_IPSYSTEMSTATSTABLE_IPSYSTEMSTATSTABLE_MODULE 1
 
/* Define if compiling with the ip-mib/ipSystemStatsTable/ipSystemStatsTable_interface module files.  */
#define USING_IP_MIB_IPSYSTEMSTATSTABLE_IPSYSTEMSTATSTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the ip-mib/ipSystemStatsTable/ipSystemStatsTable_data_access module files.  */
#define USING_IP_MIB_IPSYSTEMSTATSTABLE_IPSYSTEMSTATSTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/scalars_common module files.  */
#define USING_IP_MIB_DATA_ACCESS_SCALARS_COMMON_MODULE 1
 
/* Define if compiling with the ip-forward-mib/ipCidrRouteTable/ipCidrRouteTable module files.  */
#define USING_IP_FORWARD_MIB_IPCIDRROUTETABLE_IPCIDRROUTETABLE_MODULE 1
 
/* Define if compiling with the ip-forward-mib/inetCidrRouteTable/inetCidrRouteTable module files.  */
#define USING_IP_FORWARD_MIB_INETCIDRROUTETABLE_INETCIDRROUTETABLE_MODULE 1
 
/* Define if compiling with the tcp-mib/data_access/tcpConn module files.  */
#define USING_TCP_MIB_DATA_ACCESS_TCPCONN_MODULE 1
 
/* Define if compiling with the tcp-mib/tcpConnectionTable/tcpConnectionTable module files.  */
#define USING_TCP_MIB_TCPCONNECTIONTABLE_TCPCONNECTIONTABLE_MODULE 1
 
/* Define if compiling with the tcp-mib/tcpListenerTable/tcpListenerTable module files.  */
#define USING_TCP_MIB_TCPLISTENERTABLE_TCPLISTENERTABLE_MODULE 1
 
/* Define if compiling with the udp-mib/udpEndpointTable/udpEndpointTable module files.  */
#define USING_UDP_MIB_UDPENDPOINTTABLE_UDPENDPOINTTABLE_MODULE 1
 
/* Define if compiling with the hardware/fsys/hw_fsys module files.  */
#define USING_HARDWARE_FSYS_HW_FSYS_MODULE 1
 
/* Define if compiling with the hardware/fsys/fsys_getfsstats module files.  */
#define USING_HARDWARE_FSYS_FSYS_GETFSSTATS_MODULE 1
 
/* Define if compiling with the hardware/memory/hw_mem module files.  */
#define USING_HARDWARE_MEMORY_HW_MEM_MODULE 1
 
/* Define if compiling with the hardware/memory/memory_netbsd module files.  */
#define USING_HARDWARE_MEMORY_MEMORY_NETBSD_MODULE 1
 
/* Define if compiling with the hardware/cpu/cpu module files.  */
#define USING_HARDWARE_CPU_CPU_MODULE 1
 
/* Define if compiling with the hardware/cpu/cpu_sysctl module files.  */
#define USING_HARDWARE_CPU_CPU_SYSCTL_MODULE 1
 
/* Define if compiling with the snmp-notification-mib/snmpNotifyFilterTable/snmpNotifyFilterTable_interface module files.  */
#define USING_SNMP_NOTIFICATION_MIB_SNMPNOTIFYFILTERTABLE_SNMPNOTIFYFILTERTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the snmp-notification-mib/snmpNotifyFilterTable/snmpNotifyFilterTable_data_access module files.  */
#define USING_SNMP_NOTIFICATION_MIB_SNMPNOTIFYFILTERTABLE_SNMPNOTIFYFILTERTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the host/data_access/swinst_pkginfo module files.  */
#define USING_HOST_DATA_ACCESS_SWINST_PKGINFO_MODULE 1
 
/* Define if compiling with the host/data_access/swrun_kinfo module files.  */
#define USING_HOST_DATA_ACCESS_SWRUN_KINFO_MODULE 1
 
/* Define if compiling with the if-mib/data_access/interface module files.  */
#define USING_IF_MIB_DATA_ACCESS_INTERFACE_MODULE 1
 
/* Define if compiling with the if-mib/ifTable/ifTable_interface module files.  */
#define USING_IF_MIB_IFTABLE_IFTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the if-mib/ifTable/ifTable_data_access module files.  */
#define USING_IF_MIB_IFTABLE_IFTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the if-mib/ifXTable/ifXTable_interface module files.  */
#define USING_IF_MIB_IFXTABLE_IFXTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the if-mib/ifXTable/ifXTable_data_access module files.  */
#define USING_IF_MIB_IFXTABLE_IFXTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/ipaddress module files.  */
#define USING_IP_MIB_DATA_ACCESS_IPADDRESS_MODULE 1
 
/* Define if compiling with the ip-mib/ipAddressTable/ipAddressTable_interface module files.  */
#define USING_IP_MIB_IPADDRESSTABLE_IPADDRESSTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the ip-mib/ipAddressTable/ipAddressTable_data_access module files.  */
#define USING_IP_MIB_IPADDRESSTABLE_IPADDRESSTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the ip-mib/ipAddressPrefixTable/ipAddressPrefixTable_interface module files.  */
#define USING_IP_MIB_IPADDRESSPREFIXTABLE_IPADDRESSPREFIXTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the ip-mib/ipAddressPrefixTable/ipAddressPrefixTable_data_access module files.  */
#define USING_IP_MIB_IPADDRESSPREFIXTABLE_IPADDRESSPREFIXTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/defaultrouter module files.  */
#define USING_IP_MIB_DATA_ACCESS_DEFAULTROUTER_MODULE 1
 
/* Define if compiling with the ip-mib/ipDefaultRouterTable/ipDefaultRouterTable_interface module files.  */
#define USING_IP_MIB_IPDEFAULTROUTERTABLE_IPDEFAULTROUTERTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the ip-mib/ipDefaultRouterTable/ipDefaultRouterTable_data_access module files.  */
#define USING_IP_MIB_IPDEFAULTROUTERTABLE_IPDEFAULTROUTERTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the ip-mib/ipDefaultRouterTable/ipDefaultRouterTable_data_get module files.  */
#define USING_IP_MIB_IPDEFAULTROUTERTABLE_IPDEFAULTROUTERTABLE_DATA_GET_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/arp_common module files.  */
#define USING_IP_MIB_DATA_ACCESS_ARP_COMMON_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/arp_sysctl module files.  */
#define USING_IP_MIB_DATA_ACCESS_ARP_SYSCTL_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/systemstats_common module files.  */
#define USING_IP_MIB_DATA_ACCESS_SYSTEMSTATS_COMMON_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/systemstats_sysctl module files.  */
#define USING_IP_MIB_DATA_ACCESS_SYSTEMSTATS_SYSCTL_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/scalars_sysctl module files.  */
#define USING_IP_MIB_DATA_ACCESS_SCALARS_SYSCTL_MODULE 1
 
/* Define if compiling with the ip-forward-mib/data_access/route module files.  */
#define USING_IP_FORWARD_MIB_DATA_ACCESS_ROUTE_MODULE 1
 
/* Define if compiling with the ip-forward-mib/ipCidrRouteTable/ipCidrRouteTable_interface module files.  */
#define USING_IP_FORWARD_MIB_IPCIDRROUTETABLE_IPCIDRROUTETABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the ip-forward-mib/ipCidrRouteTable/ipCidrRouteTable_data_access module files.  */
#define USING_IP_FORWARD_MIB_IPCIDRROUTETABLE_IPCIDRROUTETABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the ip-forward-mib/inetCidrRouteTable/inetCidrRouteTable_interface module files.  */
#define USING_IP_FORWARD_MIB_INETCIDRROUTETABLE_INETCIDRROUTETABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the ip-forward-mib/inetCidrRouteTable/inetCidrRouteTable_data_access module files.  */
#define USING_IP_FORWARD_MIB_INETCIDRROUTETABLE_INETCIDRROUTETABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the tcp-mib/data_access/tcpConn_common module files.  */
#define USING_TCP_MIB_DATA_ACCESS_TCPCONN_COMMON_MODULE 1
 
/* Define if compiling with the tcp-mib/data_access/tcpConn_openbsd module files.  */
#define USING_TCP_MIB_DATA_ACCESS_TCPCONN_OPENBSD_MODULE 1
 
/* Define if compiling with the tcp-mib/tcpConnectionTable/tcpConnectionTable_interface module files.  */
#define USING_TCP_MIB_TCPCONNECTIONTABLE_TCPCONNECTIONTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the tcp-mib/tcpConnectionTable/tcpConnectionTable_data_access module files.  */
#define USING_TCP_MIB_TCPCONNECTIONTABLE_TCPCONNECTIONTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the tcp-mib/tcpListenerTable/tcpListenerTable_interface module files.  */
#define USING_TCP_MIB_TCPLISTENERTABLE_TCPLISTENERTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the tcp-mib/tcpListenerTable/tcpListenerTable_data_access module files.  */
#define USING_TCP_MIB_TCPLISTENERTABLE_TCPLISTENERTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the udp-mib/data_access/udp_endpoint module files.  */
#define USING_UDP_MIB_DATA_ACCESS_UDP_ENDPOINT_MODULE 1
 
/* Define if compiling with the udp-mib/udpEndpointTable/udpEndpointTable_interface module files.  */
#define USING_UDP_MIB_UDPENDPOINTTABLE_UDPENDPOINTTABLE_INTERFACE_MODULE 1
 
/* Define if compiling with the udp-mib/udpEndpointTable/udpEndpointTable_data_access module files.  */
#define USING_UDP_MIB_UDPENDPOINTTABLE_UDPENDPOINTTABLE_DATA_ACCESS_MODULE 1
 
/* Define if compiling with the if-mib/data_access/interface_sysctl module files.  */
#define USING_IF_MIB_DATA_ACCESS_INTERFACE_SYSCTL_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/ipaddress_common module files.  */
#define USING_IP_MIB_DATA_ACCESS_IPADDRESS_COMMON_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/ipaddress_sysctl module files.  */
#define USING_IP_MIB_DATA_ACCESS_IPADDRESS_SYSCTL_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/defaultrouter_common module files.  */
#define USING_IP_MIB_DATA_ACCESS_DEFAULTROUTER_COMMON_MODULE 1
 
/* Define if compiling with the ip-mib/data_access/defaultrouter_sysctl module files.  */
#define USING_IP_MIB_DATA_ACCESS_DEFAULTROUTER_SYSCTL_MODULE 1
 
/* Define if compiling with the ip-forward-mib/data_access/route_common module files.  */
#define USING_IP_FORWARD_MIB_DATA_ACCESS_ROUTE_COMMON_MODULE 1
 
/* Define if compiling with the ip-forward-mib/data_access/route_sysctl module files.  */
#define USING_IP_FORWARD_MIB_DATA_ACCESS_ROUTE_SYSCTL_MODULE 1
 
/* Define if compiling with the udp-mib/data_access/udp_endpoint_common module files.  */
#define USING_UDP_MIB_DATA_ACCESS_UDP_ENDPOINT_COMMON_MODULE 1
 
/* Define if compiling with the udp-mib/data_access/udp_endpoint_openbsd module files.  */
#define USING_UDP_MIB_DATA_ACCESS_UDP_ENDPOINT_OPENBSD_MODULE 1
 
